pub struct EncryptedFileMeta {
pub megolm_session_id: String,
pub wrapped_key_b64: String,
pub nonce_b64: String,
}Expand description
Metadata that lets the receiver decrypt an encrypted file: the Megolm session id used to wrap the file key, the wrapped file key itself, and the ChaCha20-Poly1305 nonce. All bytes base64-encoded.
Fields
megolm_session_id: Stringwrapped_key_b64: Stringnonce_b64: StringTrait Implementations
Sourceimpl Clone for EncryptedFileMeta
impl Clone for EncryptedFileMeta
Sourcefn clone(&self) -> EncryptedFileMeta
fn clone(&self) -> EncryptedFileMeta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EncryptedFileMeta
impl Debug for EncryptedFileMeta
Sourceimpl<'de> Deserialize<'de> for EncryptedFileMeta
impl<'de> Deserialize<'de> for EncryptedFileMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EncryptedFileMeta
impl PartialEq for EncryptedFileMeta
Sourcefn eq(&self, other: &EncryptedFileMeta) -> bool
fn eq(&self, other: &EncryptedFileMeta) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EncryptedFileMeta
impl Serialize for EncryptedFileMeta
impl Eq for EncryptedFileMeta
impl StructuralPartialEq for EncryptedFileMeta