pub struct ServerClient { /* private fields */ }Expand description
A live connection to the server. Cloneable handle; cloning shares the same underlying socket.
Implementations
Sourceimpl ServerClient
impl ServerClient
Sourcepub async fn connect(
url: &str,
dial: &DialMode,
fingerprint: String,
rooms: Vec<String>,
) -> Result<(Self, UnboundedReceiver<ServerEvent>)>
pub async fn connect( url: &str, dial: &DialMode, fingerprint: String, rooms: Vec<String>, ) -> Result<(Self, UnboundedReceiver<ServerEvent>)>
Open a connection, send the initial hello, and return the client
plus a stream of ServerEvents.
url:ws://<onion>:80/ws(onion),wss://relay/ws(clearnet TLS), orws://host:port/ws(clearnet plain / tests).dial: how to physically reach it — one of the transport “doors” (Socks5for onion via Tor,Tlsforwss://,Directforws://).
Sourcepub fn publish(&self, room: &str, id: &str, payload: &[u8]) -> Result<()>
pub fn publish(&self, room: &str, id: &str, payload: &[u8]) -> Result<()>
Send a room’s opaque wire bytes to the server for fan-out.
Sourcepub fn subscribe(&self, room: &str) -> Result<()>
pub fn subscribe(&self, room: &str) -> Result<()>
Assert membership of a room so the server mailboxes us when offline.
pub fn unsubscribe(&self, room: &str) -> Result<()>
pub fn ping(&self) -> Result<()>